@@ -2,12 +2,13 @@ import contextlib
 import inspect
 import os
 
+from latex_ji18n.biber import get_db_entries_by_type_from_dir_bib_files
 from latex_ji18n.config import Config
 from latex_ji18n.io import read_yaml_file
 
 
 class BaseContext(dict):
-    def __init__(self, config=Config, metadata_dict="__meta", **kwargs):
+    def __init__(self, config=Config, metadata_dict="__config", **kwargs):
         super().__init__(**kwargs)
 
         self._metadata_dict = metadata_dict
@@ -142,8 +143,7 @@ class ProjectContext(BaseContext):
             source_dirpath,
             "source_dirpath",
             must_exists=True,
-            not_exists_msg=("Source directory '%s' does not exists.")
-            % source_dirpath,
+            not_exists_msg=("Source directory '%s' does not exists.") % source_dirpath,
         )
 
         # src/main.template.tex
@@ -154,8 +154,7 @@ class ProjectContext(BaseContext):
             template_filepath,
             "template_filepath",
             must_exists=True,
-            not_exists_msg=("Template file '%s' does not exists.")
-            % template_filepath,
+            not_exists_msg=("Template file '%s' does not exists.") % template_filepath,
         )
 
         # dist/
@@ -183,6 +182,10 @@ class ProjectContext(BaseContext):
         )
         self._prepare_file(i18n_private_dirpath, "i18n_private_dirpath")
 
+        # Load bib databases
+        self.update({self._get_meta("bibdb_variable_name"):
+                     get_db_entries_by_type_from_dir_bib_files(source_dirpath)})
+
         self._prepared = True
 
     def load(self):
@@ -242,10 +245,16 @@ class LanguageContext(BaseContext):
         self._set_meta("language", language)
 
     @property
-    def localized_template_name(self):
+    def localized_tex_filename(self):
         schema = self.project_context._config.localized_template_name_schema()
         return schema % self._get_meta("language")
 
+    @property
+    def localized_tex_filepath(self):
+        return os.path.join(
+            self.project_context.source_dirpath, self.localized_tex_filename
+        )
+
     @property
     def filepath(self):
         _fp = self._get_meta("i18n_filepath")
